import { useCallback, useEffect, useState } from 'react'

import { get, isFunction, isString } from 'lodash'

type Cb = (parma?: any) => any
type Options = {
  defaultValue?: any;
  deps?: any[];
  immediate?: boolean;
  formatResult?: string | ((res: any) => any);
  onSuccess?: (res: any) => void;
  onError?: (res: any) => void;
}
type Result<T> = {
  data: T;
  loading: boolean;
  run: (params?: any) => Promise<any>;
}

export function useRequest<T = any> (fn: Cb, options: Options): Result<T> {
  const [loading, setLoading] = useState(false)
  const [data, setData] = useState<T>(options?.defaultValue)
  const {
    immediate = true,
    formatResult,
    onSuccess,
    onError
  } = options || {}

  const run = useCallback(async (...args: any[]) => {
    return new Promise((resolve, reject) => {
      if (isFunction(fn)) {
        if (loading) return
        setLoading(true)
        fn(...args)
          .then((res) => {
            if (formatResult) {
              if (isFunction(formatResult)) {
                res = formatResult(res)
              }
              if (isString(formatResult)) {
                res = get(res, formatResult)
              }
            }
            setData(res)
            onSuccess && onSuccess(res)
            resolve(res)
            setLoading(false)
          }).catch((error) => {
            console.log('接口请求失败：', error)
            onError && onError(error)
            reject(error)
            setLoading(false)
          })
      }
    })
  }, [fn])

  useEffect(() => {
    if (immediate) run()
  }, [])

  return {
    loading,
    data,
    run
  }
}
