import React from 'react'

import { Button, Cell, Toast } from '@arco-design/mobile-react'
import styled from 'styled-components'

import { useRequest } from '@/hooks/useRequest'

import { DeleteMahjongQueenApi, GetMahjongQueenListApi } from './services'

const LoginPage: React.FC = () => {
  const { data: dataList, run: refreshList } = useRequest<any[]>(GetMahjongQueenListApi, {
    defaultValue: [],
    formatResult: (res) => (res?.data || []),
    onSuccess: () => {
      Toast.success('刷新成功')
    },
    onError: () => {
      Toast.error('刷新失败')
    }
  })
  const { loading, run: handleClickClear } = useRequest<any[]>(DeleteMahjongQueenApi, {
    immediate: false,
    onSuccess: () => {
      Toast.success('清空成功')
      refreshList()
    },
    onError: () => {
      Toast.error('清空失败')
    }
  })

  return (
    <Layout>
      <Headers>
        <Button inline onClick={refreshList}>刷新</Button>
        <Button inline type="ghost" loading={loading} onClick={handleClickClear}>清空</Button>
      </Headers>

      <Cell.Group>
        {
          dataList.map((item) => (<Cell key={item.userId} label={item.userId} />))
        }
      </Cell.Group>
    </Layout>
  )
}

export default LoginPage

const Layout = styled.div`
  position: relative;
  width: 100%;
  height: 100vh;
  /* background: #000
    url('https://fe-internal-files-1301947356.cos.ap-beijing.myqcloud.com/public/image/background.svg')
    no-repeat 50%; */
`

const Headers = styled.div`
  display:flex;
  justify-content: center;
  > button {
    margin:10px;
  }
`
