import React, { useState, useEffect, useRef, ChangeEvent, MouseEvent, TouchEvent } from 'react'
import { useNavigate } from 'react-router-dom'

import { Button, Input } from '@arco-design/mobile-react'
import styled from 'styled-components'

const LoginPage: React.FC = () => {
  const uuid = useRef('')
  const [captchaUrl, setCaptchaUrl] = useState<string>('')
  console.log(captchaUrl)
  const navigate = useNavigate()

  useEffect(() => {
    getCaptcha()
  }, [])

  // 获取uuid 验证码
  const getCaptcha = () => {
    const s: any = []
    const hexDigits = '0123456789abcdef'
    for (let i = 0; i < 36; i++) {
      s[i] = hexDigits.substr(Math.floor(Math.random() * 0x10), 1)
    }
    s[14] = '4' // bits 12-15 of the time_hi_and_version field to 0010
    s[19] = hexDigits.substr((s[19] & 0x3) | 0x8, 1) // bits 6-7 of the clock_seq_hi_and_reserved to 01
    s[8] = s[13] = s[18] = s[23] = '-'
    const _uuid = s.join('')
    uuid.current = _uuid
    setCaptchaUrl(`${process.env.API_HOST}/hzy-admin/captcha?uuid=${_uuid}`)
  }

  const [username, setUsername] = useState('')
  const [password, setPassword] = useState('')

  const onUsernameChange = (e: ChangeEvent<HTMLInputElement>) => {
    setUsername(e.target.value)
  }
  const onPasswordChange = (e: ChangeEvent<HTMLInputElement>) => {
    setPassword(e.target.value)
  }

  const handleLogin = (e: MouseEvent | TouchEvent) => {
    console.log('登录::', username, password)
    navigate('/game-room-tools')
  }
  return (
    <LoginLayout>
      <LoginContainer>
        <LoginContainerHeader>移动端模板</LoginContainerHeader>
        <Input label="用户名" onChange={onUsernameChange} placeholder="请输入用户名" clearable border="none" />
        <Input
          label="密码"
          onChange={onPasswordChange}
          type="password"
          placeholder="请输入密码"
          clearable
          border="none"
        />
        <LoginButton needActive onClick={handleLogin}>
          Login
        </LoginButton>
      </LoginContainer>
    </LoginLayout>
  )
}

export default LoginPage

const LoginLayout = styled.div`
  position: relative;
  width: 100%;
  height: 100vh;
  /* background: #000
    url('https://fe-internal-files-1301947356.cos.ap-beijing.myqcloud.com/public/image/background.svg')
    no-repeat 50%; */
`

const LoginContainer = styled.div`
  width: 100%;
  height: 500px;
  box-sizing: border-box;
  position: absolute;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  margin: auto auto;
  background: transparent;
  padding: 20px;
  .ant-space-align-center {
    align-items: flex-start;
  }
`
const LoginContainerHeader = styled.h1`
  height: 44px;
  line-height: 44px;
  display: flex;
  align-items: center;
  justify-content: center;
  flex-direction: column;
  margin-bottom: 20px;
  font-size: 32px;
  > img {
    display: block;
    height: 44px;
    margin-bottom: 10px;
  }
  > span {
    color: rgba(0, 0, 0, 0.85);
    font-weight: 600;
  }
`

const LoginButton = styled(Button)`
  width: 90%;
  margin: 20px auto 0;
`
