import { lazy } from 'react'
import { Navigate, useRoutes } from 'react-router-dom'

import BaseLayout from '@/layouts/BaseLayout'
import Login from '@/pages/Login'

import { RouteObject } from './interface'

const GameRoomTools = lazy(() => import('@/pages/GameRoomTools/index'))
const Home = lazy(() => import('@/pages/Home/index'))

export const rootRouter: RouteObject[] = [
  {
    path: '/',
    element: <Navigate to="/home" />
  },
  {
    path: '/Login',
    element: <Login />,
    meta: {
      auth: false,
      title: '登录页',
      key: 'login'
    }
  },
  {
    element: <BaseLayout />,
    children: [
      {
        path: '/game-room-tools',
        name: '首页',
        element: <GameRoomTools />,
        meta: {
          auth: false,
          title: '首页',
          key: 'home'
        }
      },
      {
        path: '/home',
        name: '视频旋转',
        element: <Home />,
        meta: {
          auth: false,
          title: '视频旋转',
          key: 'home'
        }
      }
    ]
  }
  // 异常页面
  // { path: '*',  element: <Pack /> }
]
const Routes = () => {
  const routes = useRoutes(rootRouter)
  return routes
}
export default Routes
