import { createSlice, PayloadAction } from '@reduxjs/toolkit'

export const NAMESPACE_KEY = 'user'

type State = {
  status: 'idle' | 'loading' | 'succeeded' | 'failed',
  isLogin: boolean
  username: string
  password: string
  token: string
  remember: boolean
  avatar?: string
  createTime: number
  dept: string
  deptId: number
  deptList: string
  email: string
  enabled: boolean
  licenseExpired: boolean
  nickname: string
  phone: string
  roleIdList: string
  roles: string[]
  userLoginInfo: {
    address: string
    device: string
    ip: string
    lastLoginTime: number
  },
  authRouter: string[]
}

const initialState: State = {
  status: 'idle',
  isLogin: false,
  username: '',
  password: '',
  token: '',
  remember: false,
  avatar: '',
  createTime: 0,
  dept: '',
  deptId: 0,
  deptList: '',
  email: '',
  enabled: false,
  licenseExpired: false,
  nickname: '',
  phone: '',
  roleIdList: '',
  roles: [],
  userLoginInfo: {
    address: '',
    device: '',
    ip: '',
    lastLoginTime: 0
  },
  authRouter: []
}

const { reducer, actions } = createSlice({
  name: NAMESPACE_KEY,
  initialState,
  reducers: {
    // login(state, { payload }: PayloadAction<Partial<State>>) {
    //   Object.assign(state, payload)
    // },
    setAuthRouter (state, { payload }: PayloadAction<string[]>) {
      state.authRouter = payload
    },
    setLogin (state, { payload }: PayloadAction<any>) {
      state.token = payload?.token
      state.username = payload?.username
      state.isLogin = true
    },
    setLogout (state) {
      state.token = ''
      state.isLogin = false
    }
  }
})

export const { setAuthRouter, setLogin, setLogout } = actions
export default reducer
